from __future__ import unicode_literals
from django.conf.urls import patterns, url, include
from .views import UserList, UserDetail
from .views import CategoryList, CategoryDetail
from .views import PageList, PageDetail
from .views import PostList, PostDetail

user_urls = patterns('',
    url(r'^/(?P<id>[0-9]+)$', UserDetail.as_view(), name='user-detail'),
    url(r'^$', UserList.as_view(), name='user-list')
)

category_urls = patterns('',
    url(r'^/(?P<id>[0-9]+)$', CategoryDetail.as_view(), name='category-detail'),
    url(r'^$', CategoryList.as_view(), name='category-list')
)

page_urls = patterns('',
    url(r'^/(?P<id>[0-9]+)$', PageDetail.as_view(), name='page-detail'),
    url(r'^$', PageList.as_view(), name='page-list')
)

post_urls = patterns('',
    url(r'^/(?P<id>\d+)$', PostDetail.as_view(), name='post-detail'),
    url(r'^$', PostList.as_view(), name='post-list')
)

urlpatterns = patterns('',
    url(r'^users', include(user_urls)),
    url(r'^categories', include(category_urls)),
    url(r'^pages', include(page_urls)),
    url(r'^posts', include(post_urls)),
    url("^", include('rest_framework_swagger.urls')),
)




REST_FRAMEWORK = {
    'DEFAULT_FILTER_BACKENDS': ('rest_framework.filters.DjangoFilterBackend'),
    'TEST_REQUEST_DEFAULT_FORMAT': 'json',
}

SWAGGER_SETTINGS = {
    'exclude_namespaces': [],
    'api_version': '0.1',
    'api_path': '/',
    'api_key': '',
    'is_authenticated': False,
    'is_superuser': False,
    'permission_denied_handler': None,
    'info': {
        'title': 'Web API Documentation',
        'description': 'The web API package exposes Mezzanine data through a REST API using JSON serialization. Bugs should be reported on <a href="https://github.com/gcushen/mezzanine-api/issues" target="_blank">Github</a>.',
    },
    'doc_expansion': 'none',
}



from rest_framework import serializers
from django.contrib.sites.models import Site
from django.contrib.auth.models import User
from mezzanine.blog.models import BlogPost as Post, BlogCategory
from mezzanine.pages.models import Page
from mezzanine.generic.models import ThreadedComment


class UserSerializer(serializers.ModelSerializer):
    """
    Serializing all the users
    """
    
    class Meta:
        model = User
        fields = ('id', 'username', 'email', 'first_name', 'last_name')


class CategorySerializer(serializers.ModelSerializer):
    """
    Serializing all the categories
    """
    
    class Meta:
        model = BlogCategory
        fields = ('id', 'title', 'slug')


class PageSerializer(serializers.ModelSerializer):
    """
    Serializing all the pages
    """
    
    class Meta:
        model = Page
        fields = ('id', 'parent', 'title', 'description', 'slug')


class PostSerializer(serializers.ModelSerializer):
    """
    Serializing all the blog posts
    """
    
    user = UserSerializer(required=False)
    categories = CategorySerializer(many=True, required=False, read_only=True)
    url = serializers.URLField(source='get_absolute_url_with_host', read_only=True)
    short_url = serializers.CharField(source='get_absolute_url', read_only=True)

    class Meta:
        model = Post
        fields = ('id', 'user', 'publish_date', 'updated', 'title', 'url', 'short_url', 'content', 'slug',
                  'categories', 'allow_comments', 'comments_count', 'keywords_string', 'featured_image')




from rest_framework import generics, permissions
from .serializers import UserSerializer, PostSerializer, CategorySerializer, PageSerializer
from django.contrib.sites.models import Site
from django.contrib.auth.models import User
from mezzanine.blog.models import BlogPost as Post, BlogCategory
from mezzanine.pages.models import Page
from mezzanine.generic.models import ThreadedComment


class UserList(generics.ListAPIView):
    """
    API endpoint that allows all users to be viewed
    """
    
    queryset = User.objects.all()
    serializer_class = UserSerializer

class UserDetail(generics.RetrieveAPIView):
    """
    API endpoint that allows a specific user to be viewed
    """
    
    queryset = User.objects.all()
    serializer_class = UserSerializer
    lookup_field = 'id'

class CategoryList(generics.ListAPIView):
    """
    API endpoint that allows all categories to be viewed
    """
    
    queryset = BlogCategory.objects.all()
    serializer_class = CategorySerializer

class CategoryDetail(generics.RetrieveAPIView):
    """
    API endpoint that allows a specific category to be viewed
    """
    
    queryset = BlogCategory.objects.all()
    serializer_class = CategorySerializer
    lookup_field = 'id'

class PageList(generics.ListAPIView):
    """
    API endpoint that allows all pages to be viewed
    """
    
    queryset = Page.objects.all()
    serializer_class = PageSerializer

class PageDetail(generics.RetrieveAPIView):
    """
    API endpoint that allows a specific page to be viewed
    """
    
    queryset = Page.objects.all()
    serializer_class = PageSerializer
    lookup_field = 'id'

class PostList(generics.ListAPIView):
    """
    API endpoint that allows all blog posts to be viewed
    """
    
    queryset = Post.objects.all()
    serializer_class = PostSerializer

class PostDetail(generics.RetrieveAPIView):
    """
    API endpoint that allows a specific blog post to be viewed
    """
    
    queryset = Post.objects.all()
    serializer_class = PostSerializer
    lookup_field = 'id'



import os
import sys
from setuptools import setup, find_packages
from api import __version__ as version

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

if sys.argv[:2] == ["setup.py", "bdist_wheel"]:
    # Remove previous build dir when creating a wheel build
    try:
        rmtree("build")
    except:
        pass

setup(
    name='mezzanine-api',
    version=version,
    author='George Cushen',
    author_email='mezzanine-users@googlegroups.com',   
    url='http://github.com/gcushen/mezzanine-api',   
    description='A RESTful web API for Mezzanine CMS.',
    long_description=open("README.rst", 'rb').read().decode('utf-8'),
    keywords='mezzanine rest restful web api',
    include_package_data=True,
    license='BSD License',   
    packages=find_packages(),
    install_requires=[
        "mezzanine",
        "django-rest-swagger==0.2.9",
        "djangorestframework==3.1.1",
        "markdown",
        "django-filter"
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Internet :: WWW/HTTP :: WSGI',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)
